# Django Access Log


## Add packge to INSTALLED_APPS

```python

INSTALLED_APPS = [
    ...
    'django_app_logs',
]

```

## Make migrations

```python

python manage.py makemigrations
python manage.py migrate

```